@@ -231,6 +231,18 @@ class TestUnidiffParser(unittest.TestCase):
         with open(utf8_file, 'r') as diff_file:
             self.assertRaises(UnidiffParseError, PatchSet, diff_file)
 
+    def test_from_filename_with_cr_in_diff_text_files(self):
+        """Parse git diff text files that contain CR"""
+        utf8_file = os.path.join(self.samples_dir, 'samples/git_cr.diff')
+        self.assertRaises(UnidiffParseError, PatchSet.from_filename, utf8_file)
+
+        ps1 = PatchSet.from_filename(utf8_file, newline='\n')
+        import io
+        with io.open(utf8_file, 'r', newline='\n') as diff_file:
+            ps2 = PatchSet(diff_file)
+
+        self.assertEqual(ps1, ps2)
+
     def test_parse_diff_with_new_and_modified_binary_files(self):
         """Parse git diff file with newly added and modified binaries files."""
         utf8_file = os.path.join(self.samples_dir, 'samples/sample8.diff')
@@ -238,26 +250,38 @@ class TestUnidiffParser(unittest.TestCase):
             res = PatchSet(diff_file)
 
         # three file in the patch
-        self.assertEqual(len(res), 3)
+        self.assertEqual(len(res), 5)
 
-        # first file is added
+        # first empty file is added
         self.assertFalse(res[0].is_modified_file)
         self.assertFalse(res[0].is_removed_file)
         self.assertTrue(res[0].is_added_file)
-        self.assertTrue(res[0].is_binary_file)
+        self.assertFalse(res[0].is_binary_file)
 
-        # second file is modified
-        self.assertTrue(res[1].is_modified_file)
+        # second file is added
+        self.assertFalse(res[1].is_modified_file)
         self.assertFalse(res[1].is_removed_file)
-        self.assertFalse(res[1].is_added_file)
+        self.assertTrue(res[1].is_added_file)
         self.assertTrue(res[1].is_binary_file)
 
-        # third file is removed
-        self.assertFalse(res[2].is_modified_file)
-        self.assertTrue(res[2].is_removed_file)
+        # third file is modified
+        self.assertTrue(res[2].is_modified_file)
+        self.assertFalse(res[2].is_removed_file)
         self.assertFalse(res[2].is_added_file)
         self.assertTrue(res[2].is_binary_file)
 
+        # fourth file is removed
+        self.assertFalse(res[3].is_modified_file)
+        self.assertTrue(res[3].is_removed_file)
+        self.assertFalse(res[3].is_added_file)
+        self.assertTrue(res[3].is_binary_file)
+
+        # fifth empty file is added
+        self.assertFalse(res[4].is_modified_file)
+        self.assertFalse(res[4].is_removed_file)
+        self.assertTrue(res[4].is_added_file)
+        self.assertFalse(res[4].is_binary_file)
+
     def test_parse_round_trip_with_binary_files_in_diff(self):
         """Parse git diff with binary files though round trip"""
         utf8_file = os.path.join(self.samples_dir, 'samples/sample8.diff')
